@@ -35,6 +35,7 @@ class SQLParser(Parser):
        'union',
        'select',
        'insert',
+       'update',
        'delete',
        'drop_view',
        )
@@ -200,6 +201,15 @@ class SQLParser(Parser):
 
         return Delete(table=p.from_table, where=where)
 
+    # UPDATE
+    @_('UPDATE identifier SET update_parameter_list')
+    @_('UPDATE identifier SET update_parameter_list WHERE expr')
+    def update(self, p):
+        where = getattr(p, 'expr', None)
+        return Update(table=p.identifier,
+                      update_columns=p.update_parameter_list,
+                      where=where)
+
     # INSERT
     @_('INSERT INTO from_table LPAREN result_columns RPAREN select')
     @_('INSERT INTO from_table select')
@@ -536,6 +546,10 @@ class SQLParser(Parser):
             p.expr.parentheses = True
         return p.expr
 
+    @_('id LPAREN expr FROM expr RPAREN')
+    def function(self, p):
+        return Function(op=p.id, args=[p.expr0], from_arg=p.expr1)
+
     @_('id LPAREN DISTINCT expr_list RPAREN')
     def function(self, p):
         return Function(op=p.id, distinct=True, args=p.expr_list)
@@ -560,6 +574,10 @@ class SQLParser(Parser):
     def expr_list_or_nothing(self, p):
         pass
 
+    @_('CAST LPAREN expr AS id LPAREN integer RPAREN RPAREN')
+    def expr(self, p):
+        return TypeCast(arg=p.expr, type_name=str(p.id), length=p.integer)
+
     @_('CAST LPAREN expr AS id RPAREN')
     def expr(self, p):
         return TypeCast(arg=p.expr, type_name=str(p.id))
@@ -614,6 +632,18 @@ class SQLParser(Parser):
     def expr(self, p):
         return UnaryOperation(op=p[0], args=(p.expr,))
 
+    # update fields list
+    @_('update_parameter',
+       'update_parameter_list COMMA update_parameter')
+    def update_parameter_list(self, p):
+        params = getattr(p, 'update_parameter_list', {})
+        params.update(p.update_parameter)
+        return params
+
+    @_('id EQUALS expr')
+    def update_parameter(self, p):
+        return {p.id: p.expr}
+
     # EXPRESSIONS
 
     @_('enumeration COMMA expr')
